@@ -10,37 +10,33 @@
 #endif
 
 #include <memory>
+#include <string>
 #include <type_traits>
 #include <unordered_map>
 #include <utility>
 #include <vector>
 
+#include <wpi/sendable/SendableBuilder.h>
+
 #include "frc2/command/CommandBase.h"
-#include "frc2/command/CommandGroupBase.h"
 #include "frc2/command/PrintCommand.h"
 
 namespace frc2 {
 /**
- * Runs one of a selection of commands, either using a selector and a key to
- * command mapping, or a supplier that returns the command directly at runtime.
- * Does not actually schedule the selected command - rather, the command is run
- * through this command; this ensures that the command will behave as expected
- * if used as part of a CommandGroup.  Requires the requirements of all included
- * commands, again to ensure proper functioning when used in a CommandGroup.  If
- * this is undesired, consider using ScheduleCommand.
+ * A command composition that runs one of a selection of commands, either using
+ * a selector and a key to command mapping, or a supplier that returns the
+ * command directly at runtime.
  *
- * <p>As this command contains multiple component commands within it, it is
- * technically a command group; the command instances that are passed to it
- * cannot be added to any other groups, or scheduled individually.
- *
- * <p>As a rule, CommandGroups require the union of the requirements of their
- * component commands.
+ * <p>The rules for command compositions apply: command instances that are
+ * passed to it are owned by the composition and cannot be added to any other
+ * composition or scheduled individually, and the composition requires all
+ * subsystems its components require.
  */
 template <typename Key>
 class SelectCommand : public CommandBase {
  public:
   /**
-   * Creates a new selectcommand.
+   * Creates a new SelectCommand.
    *
    * @param commands the map of commands to choose from
    * @param selector the selector to determine which command to run
@@ -59,14 +55,16 @@ class SelectCommand : public CommandBase {
      ...);
 
     for (auto&& command : foo) {
-      if (!CommandGroupBase::RequireUngrouped(*command.second)) {
-        return;
-      }
+      CommandScheduler::GetInstance().RequireUngrouped(command.second.get());
     }
 
     for (auto&& command : foo) {
       this->AddRequirements(command.second->GetRequirements());
       m_runsWhenDisabled &= command.second->RunsWhenDisabled();
+      if (command.second->GetInterruptionBehavior() ==
+          Command::InterruptionBehavior::kCancelSelf) {
+        m_interruptBehavior = Command::InterruptionBehavior::kCancelSelf;
+      }
       m_commands.emplace(std::move(command.first), std::move(command.second));
     }
   }
@@ -76,14 +74,16 @@ class SelectCommand : public CommandBase {
       std::vector<std::pair<Key, std::shared_ptr<Command>>>&& commands)
       : m_selector{std::move(selector)} {
     for (auto&& command : commands) {
-      if (!CommandGroupBase::RequireUngrouped(*command.second)) {
-        return;
-      }
+      CommandScheduler::GetInstance().RequireUngrouped(command.second);
     }
 
     for (auto&& command : commands) {
       this->AddRequirements(command.second->GetRequirements());
       m_runsWhenDisabled &= command.second->RunsWhenDisabled();
+      if (command.second->GetInterruptionBehavior() ==
+          Command::InterruptionBehavior::kCancelSelf) {
+        m_interruptBehavior = Command::InterruptionBehavior::kCancelSelf;
+      }
       m_commands.emplace(std::move(command.first), std::move(command.second));
     }
   }
@@ -98,7 +98,10 @@ class SelectCommand : public CommandBase {
    * Creates a new selectcommand.
    *
    * @param toRun a supplier providing the command to run
+   * @deprecated Replace with {@link ProxyCommand},
+   * composing multiple of them in a {@link ParallelRaceGroup} if needed.
    */
+  WPI_DEPRECATED("Replace with ProxyCommand")
   explicit SelectCommand(std::function<std::shared_ptr<Command>()> toRun)
       : m_toRun{std::move(toRun)} {}
 
@@ -116,6 +119,25 @@ class SelectCommand : public CommandBase {
 
   bool RunsWhenDisabled() const override { return m_runsWhenDisabled; }
 
+  Command::InterruptionBehavior GetInterruptionBehavior() const override {
+    return m_interruptBehavior;
+  }
+
+  void InitSendable(wpi::SendableBuilder& builder) override {
+    CommandBase::InitSendable(builder);
+
+    builder.AddStringProperty(
+        "selected",
+        [this] {
+          if (m_selectedCommand) {
+            return m_selectedCommand->GetName();
+          } else {
+            return std::string{"null"};
+          }
+        },
+        nullptr);
+  }
+
  protected:
   // std::shared_ptr<Command> TransferOwnership() && override {
   //   return std::make_unique<SelectCommand>(std::move(*this));
@@ -127,6 +149,8 @@ class SelectCommand : public CommandBase {
   std::function<std::shared_ptr<Command>()> m_toRun;
   std::shared_ptr<Command> m_selectedCommand;
   bool m_runsWhenDisabled = true;
+  Command::InterruptionBehavior m_interruptBehavior{
+      Command::InterruptionBehavior::kCancelIncoming};
 };
 
 template <typename T>
