@@ -11,12 +11,11 @@
 
 #include <limits>
 #include <memory>
+#include <span>
 #include <type_traits>
 #include <utility>
 #include <vector>
 
-#include <wpi/span.h>
-
 #include "frc2/command/CommandGroupBase.h"
 #include "frc2/command/CommandHelper.h"
 
@@ -25,30 +24,32 @@ namespace frc2 {
 const size_t invalid_index = std::numeric_limits<size_t>::max();
 
 /**
- * A CommandGroups that runs a list of commands in sequence.
+ * A command composition that runs a list of commands in sequence.
  *
- * <p>As a rule, CommandGroups require the union of the requirements of their
- * component commands.
+ * <p>The rules for command compositions apply: command instances that are
+ * passed to it are owned by the composition and cannot be added to any other
+ * composition or scheduled individually, and the composition requires all
+ * subsystems its components require.
  */
 class SequentialCommandGroup
     : public CommandGroupBase {
  public:
   /**
-   * Creates a new SequentialCommandGroup.  The given commands will be run
-   * sequentially, with the CommandGroup finishing when the last command
+   * Creates a new SequentialCommandGroup. The given commands will be run
+   * sequentially, with the composition finishing when the last command
    * finishes.
    *
-   * @param commands the commands to include in this group.
+   * @param commands the commands to include in this composition.
    */
   explicit SequentialCommandGroup(
       std::vector<std::shared_ptr<Command>>&& commands);
 
   /**
-   * Creates a new SequentialCommandGroup.  The given commands will be run
-   * sequentially, with the CommandGroup finishing when the last command
+   * Creates a new SequentialCommandGroup. The given commands will be run
+   * sequentially, with the composition finishing when the last command
    * finishes.
    *
-   * @param commands the commands to include in this group.
+   * @param commands the commands to include in this composition.
    */
   template <class... Types,
             typename = std::enable_if_t<std::conjunction_v<
@@ -76,42 +77,32 @@ class SequentialCommandGroup
     AddCommands(std::move(foo));
   }
 
-  void Initialize() override;
+  void Initialize() final;
 
-  void Execute() override;
+  void Execute() final;
 
-  void End(bool interrupted) override;
+  void End(bool interrupted) final;
 
-  bool IsFinished() override;
+  bool IsFinished() final;
 
   bool RunsWhenDisabled() const override;
 
-  // std::shared_ptr<Subsystem> BeforeStarting(
-  //     std::function<void()> toRun,
-  //     wpi::span<std::shared_ptr<Subsystem>> requirements = {})
-  //     override;
+  Command::InterruptionBehavior GetInterruptionBehavior() const override;
 
-  // std::shared_ptr<Subsystem> AndThen(
-  //     std::function<void()> toRun,
-  //     wpi::span<std::shared_ptr<Subsystem>> requirements = {})
-  //     override;
+  void InitSendable(wpi::SendableBuilder& builder) override;
 
  public:
   void AddCommands(std::vector<std::shared_ptr<Command>>&& commands) final;
 
+ private:
+
   wpi::SmallVector<std::shared_ptr<Command>, 4> m_commands;
   size_t m_currentCommandIndex{invalid_index};
   bool m_runWhenDisabled{true};
+  Command::InterruptionBehavior m_interruptBehavior{
+      Command::InterruptionBehavior::kCancelIncoming};
 };
 
-
-std::shared_ptr<SequentialCommandGroup> SequentialCommandGroup_BeforeStarting(
-  std::shared_ptr<SequentialCommandGroup> self,
-    std::function<void()> toRun, wpi::span<std::shared_ptr<Subsystem>> requirements);
-std::shared_ptr<SequentialCommandGroup> SequentialCommandGroup_AndThen(
-    std::shared_ptr<SequentialCommandGroup> self,
-    std::function<void()> toRun, wpi::span<std::shared_ptr<Subsystem>> requirements);
-
 }  // namespace frc2
 
 #ifdef _WIN32
