@@ -5,25 +5,33 @@
 #pragma once
 
 #include <memory>
+#include <string_view>
 
+#include <networktables/BooleanTopic.h>
 #include <networktables/NetworkTable.h>
 #include <networktables/NetworkTableInstance.h>
-#include <wpi/Twine.h>
 
 #include "Button.h"
 
 namespace frc2 {
 /**
- * A {@link Button} that uses a {@link NetworkTable} boolean field.
+ * A Button that uses a NetworkTable boolean field.
  */
 class NetworkButton : public Button {
  public:
   /**
    * Creates a NetworkButton that commands can be bound to.
    *
-   * @param entry The entry that is the value.
+   * @param topic The boolean topic that contains the value.
    */
-  explicit NetworkButton(nt::NetworkTableEntry entry);
+  explicit NetworkButton(nt::BooleanTopic topic);
+
+  /**
+   * Creates a NetworkButton that commands can be bound to.
+   *
+   * @param sub The boolean subscriber that provides the value.
+   */
+  explicit NetworkButton(nt::BooleanSubscriber sub);
 
   /**
    * Creates a NetworkButton that commands can be bound to.
@@ -32,7 +40,7 @@ class NetworkButton : public Button {
    * @param field The field that is the value.
    */
   NetworkButton(std::shared_ptr<nt::NetworkTable> table,
-                const wpi::Twine& field);
+                std::string_view field);
 
   /**
    * Creates a NetworkButton that commands can be bound to.
@@ -40,6 +48,16 @@ class NetworkButton : public Button {
    * @param table The table where the networktable value is located.
    * @param field The field that is the value.
    */
-  NetworkButton(const wpi::Twine& table, const wpi::Twine& field);
+  NetworkButton(std::string_view table, std::string_view field);
+
+  /**
+   * Creates a NetworkButton that commands can be bound to.
+   *
+   * @param inst The NetworkTable instance to use
+   * @param table The table where the networktable value is located.
+   * @param field The field that is the value.
+   */
+  NetworkButton(nt::NetworkTableInstance inst, std::string_view table,
+                std::string_view field);
 };
 }  // namespace frc2
